MethodChannelOpenWithApp class

An implementation of OpenWithAppPlatform that uses method channels.

Inheritance

Constructors

MethodChannelOpenWithApp()

Properties

fileStreamChannel → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
initialFileChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFileStream() → Stream<String>
Returns a stream of file paths opened while the app is running.
override
getInitialFile() → Future<String?>
Returns the path of the file that opened the app, if any.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited